@@ -1,6 +1,9 @@
 package Mastodon::Role::UserAgent;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
+
+use strict;
+use warnings;
 
 use v5.10.0;
 use Moo::Role;
@@ -161,7 +164,7 @@ sub _request {
 
     # Some API calls return empty objects, which cannot be coerced
     if ($response->decoded_content ne '{}') {
-      if ($self->coerce_entities) {
+      if ($url !~ /oauth/ and $self->coerce_entities) {
         use Mastodon::Types qw( to_Entity );
         $data = (ref $data eq 'ARRAY')
           ? [ map { to_Entity($_) } @{$data} ]
