@@ -1,6 +1,9 @@
 package Mastodon::Types;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
+
+use strict;
+use warnings;
 
 use Type::Library -base;
 
